<?php
/*
Plugin Name: AOF SEO Site Verifier
Plugin URI: http://www.affiliatesonfire.com/articles/aof-seo-site-verifier-wordpress-plugin
Description: Easy to use site verify for Google Webmaster tools and Yahoo Site Explorer.
Version: 1.3
Author: Jonathan Marsters
Author URI: http://www.affiliatesonfire.com
*/



/*	Copyright 2008  Jonathan Marsters  (email : PLUGIN AUTHOR EMAIL)

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

	function aof_is_really_the_frontpage()
	{
		// This helper function tells us whether we are at the static frontpage.
		// Portions of this code for this function copied from M. Stegink's is_frontpage() function
		//
		// References:
		//  http://trac.wordpress.org/ticket/3682
		//  M. Stegink  http://www.bos89.nl/plugins/

		global $wp_version;

		if ($wp_version < 2.1)
		{
			// WP versions prior to 2.1 always return TRUE for is_home() when at the front page
			return(is_home());
		}
		else if ($wp_version >= 2.1)
		{
			// WP versions 2.1 and up complicate matters by not returning TRUE for is_home()
			// when at a front page which has been manually set (functionality which wasn't available prior to 2.1)
			global $post;
			$id = $post->ID;  // the_ID() is only available within the loop but global $post can be accessed any time
			$show_on_front = get_option('show_on_front');
			$page_on_front = get_option('page_on_front');

			if ($show_on_front == 'page' && $page_on_front == $id )
			{
				return true;
			} else {
				return is_home();
			}
		}
		// It looks like there will be an is_front() function coming in WP 2.4 (2.5?) which will provide the test we need	
	}

	function aof_seo_site_verify()
	// This is the main plug-in function which gets activated on the relevant rule.
	// In our case this is every time a page is written out with an (x)HTML header.
	// (As long as the theme write has included the standard wp_head() function in the theme).
	{
		// The META key is only required on the home/root page of the blog
		// so only write it on the root page
		if (aof_is_really_the_frontpage())
		{
			echo "\n";
			echo "<!-- Site verification by AOF SEO Site Verifier Wordpress plugin -->\n";

        		$google_meta_key  = get_option('aof_seo_site_verify_google_meta_key');
        		$yahoo_meta_key   = get_option('aof_seo_site_verify_yahoo_meta_key');
        		$msn_meta_key     = get_option('aof_seo_site_verify_msn_meta_key');

			if ("$google_meta_key" != "")
			{
				echo "<META name=\"verify-v1\" content=\"$google_meta_key\" />\n";
			}

			if ("$yahoo_meta_key" != "")
			{
				echo "<META name=\"y_key\" content=\"$yahoo_meta_key\" />\n";
			}

			if ("$msn_meta_key" != "")
			{
				echo "<META name=\"msvalidate.01\" content=\"$msn_meta_key\" />\n";
			}

			echo "<!-- Site verification by AOF SEO Site Verifier Wordpress plugin -->\n";
		}
	}



	function aof_seo_site_verify_admin_actions()
	{
		// Add the options page.
		// This is added as a submenu to the plugins page so that it naturally fits as "plugin options"
		// rather than general options
		add_submenu_page('plugins.php', __('AOF SEO Site Verifier options'), __('AOF SEO Site Verifier options'), 'manage_options', basename(__FILE__), 'aof_seo_site_verify_menu');
	}


	// This plug-in needs to deposit meta information in the (x)HTML header so must be run on the wp_head action.
	add_action('wp_head', 'aof_seo_site_verify');

	// Add the action to set up our admin menu
	add_action('admin_menu', 'aof_seo_site_verify_admin_actions');


	//Make our admin page function
	function aof_seo_site_verify_menu()
	{
		//Check if the admin form has been submited
		if(isset($_POST['submitted']))
		{
	        	//Get form data
	        	$google_meta_key  = $_POST['google_meta_key'];
	        	$yahoo_meta_key   = $_POST['yahoo_meta_key'];
	        	$msn_meta_key     = $_POST['msn_meta_key'];
	        	//Update plugin options
			//The first parameter is the name of the option and the second is the value, this will be stored in the database by WordPress
	        	update_option("aof_seo_site_verify_google_meta_key", "$google_meta_key"); 
	        	update_option("aof_seo_site_verify_yahoo_meta_key", "$yahoo_meta_key"); 
	        	update_option("aof_seo_site_verify_msn_meta_key", "$msn_meta_key"); 
	        	//echo a pretty 'Options Edited' message
	        	echo "<div id=\"message\" class=\"updated fade\"><p><strong>".__('AOF SEO Site Verify plugin options updated.')."</strong></p></div>";
		}
		//echo the code for a nice container for our plugin admin page
?>
<div class="wrap">
<h2><?php __('AOF SEO Site Verify plugin setup'); ?></h2>
<br />
<?php _e('You can configure <strong>AOF\'s SEO Site verification plugin</strong> here.'); ?>
<?php _e('You can change the verification key for Yahoo, Google and MSN SEO site tools here.'); ?>
<br />
<?php echo __('For support, please visit ').'<a href="http://www.affiliatesonfire.com/articles/aof-seo-site-verifier-wordpress-plugin" target="_new">Affiliates on Fire</a>.'; ?>
<br />
<?php _e('To remove site verification for a tool, clear any characters in the corresponding input box and click "Update Options".'); ?>
<form method="post" name="options" target="_self">
<table class="optiontable">
  <tr>
    <th scope="row">
      <?php _e('Google Webmaster site verify verify-v1='); ?>
    </th>
    <td>
      <input name="google_meta_key" type="text" size="40" value="<?php echo get_option('aof_seo_site_verify_google_meta_key'); ?>" />
      <br />
      <?php _e('Verify your site with Google webmaster tools to gain access to indexing, search and link statistics from Google.'); ?>
      <a href="http://www.google.com/webmasters" target="_new"><?php _e('Visit Google webmaster tools (opens in a new window)'); ?></a>
      <br />
      <?php _e('Be sure to verify with the META option not the file upload option.  This plugin inserts the verification META into the generated output.'); ?>
    </td>
  </tr>
  <tr>
    <th scope="row">
      <?php _e('Yahoo Site Explorer y_key='); ?>
    </th>
    <td>
      <input name="yahoo_meta_key" type="text" size="40" value="<?php echo get_option('aof_seo_site_verify_yahoo_meta_key'); ?>" />
      <br />
      <?php _e('Verify your site with Yahoo site explorer to gain access to indexing, search and link statistics from Yahoo.'); ?>
      <a href="http://siteexplorer.search.yahoo.com" target="_new"><?php _e('Visit Yahoo site explorer (opens in a new window)'); ?></a>
      <br />
      <?php _e('Be sure to copy the META key not the file upload key.  This plugin inserts the verification META into the generated output.'); ?>
    </td>
  </tr>
  <tr>
    <th scope="row">
      <?php _e('MSN Webmaster Site tools msvalidate.01='); ?>
    </th>
    <td>
      <input name="msn_meta_key" type="text" size="40" value="<?php echo get_option('aof_seo_site_verify_msn_meta_key'); ?>" />
      <br />
      <?php _e('Verify your site with MSN webmaster tools to gain access to indexing, search and link statistics from MSN.'); ?>
      <a href="http://webmaster.live.com" target="_new"><?php _e('Visit MSN Webmaster tools (opens in a new window)'); ?></a>
      <br />
      <?php _e('This plugin inserts the verification META into the generated output.'); ?>
    </td>
  </tr>
</table>
<p class="submit">
<input name="submitted" type="hidden" value="yes" />
<input type="submit" name="Submit" value="Update Options &raquo;" />
</p>
</form></div>
<?php
	}
?>
